searchData={"items":[{"type":"module","title":"Kino.Toast","doc":"A Kino component for displaying toast-style notifications in Elixir Livebook apps.\nThis module provides a simple way to create and manage toast notifications\nwith various styles such as info, success, warning, and error.","ref":"Kino.Toast.html"},{"type":"module","title":"Usage - Kino.Toast","doc":"To use this module, first create a new toast instance:\n\n```elixir\ncontainer = Kino.Toast.new(max_toasts: 5, dismiss_after: 5000)\n```\n\nThen, you can queue toasts to be displayed:\n\n```elixir\nKino.Toast.queue(container, Kino.Toast.info(\"This is an info message\"))\nKino.Toast.queue(container, Kino.Toast.success(\"Operation completed successfully!\"))\n```","ref":"Kino.Toast.html#module-usage"},{"type":"module","title":"Notes - Kino.Toast","doc":"- Do not immediately queue a toast after creating the instance, as it requires a moment to connect to the LiveView.\n- If you have an idea for solving this, please open a pull request on the GitHub repository.","ref":"Kino.Toast.html#module-notes"},{"type":"module","title":"Instance Options - Kino.Toast","doc":"- `:max_toasts` - Maximum number of toasts to display at once (default: 3).\n- `:dismiss_after` - Time in milliseconds after which the toast will automatically dismiss (default: 3000).","ref":"Kino.Toast.html#module-instance-options"},{"type":"module","title":"Toast Types - Kino.Toast","doc":"- `Kino.Toast.info/2`: Creates an info toast with default styling.\n- `Kino.Toast.success/2`: Creates a success toast with default styling.\n- `Kino.Toast.warning/2`: Creates a warning toast with default styling.\n- `Kino.Toast.error/2`: Creates an error toast with default styling.\n- `Kino.Toast.custom/2`: Creates a custom toast with an icon or emoji.","ref":"Kino.Toast.html#module-toast-types"},{"type":"module","title":"Customization - Kino.Toast","doc":"You can customize the appearance of toasts by providing options such as `:icon`, `:emoji`, `:background_color`,\nand `:text_color` when creating a custom toast. The default styles can also be overridden by passing these options\nto the respective toast functions.","ref":"Kino.Toast.html#module-customization"},{"type":"module","title":"Example of Custom Toast - Kino.Toast","doc":"```elixir\nKino.Toast.custom(\"Custom toast with icon\", icon: \"bell\", background_color: \"#f0f0f0\", text_color: \"#333\")\n```","ref":"Kino.Toast.html#module-example-of-custom-toast"},{"type":"function","title":"Kino.Toast.custom/2","doc":"Creates a custom toast with optional icon or emoji.\n\nOptions:\n- `:icon` - FontAwesome icon class (e.g. \"`bell`\")\n- `:emoji` - Emoji character (e.g. \"`🔔`\")\n- `:background_color` - background color hex or CSS color string (default: \"`#fff`\")\n- `:text_color` - text color hex or CSS color string (default: \"`#000`\")\n\nIf both `:icon` and `:emoji` are provided, raises ArgumentError.","ref":"Kino.Toast.html#custom/2"},{"type":"function","title":"Kino.Toast.error/2","doc":"Creates an error toast with default styling.\n\nTo customize, use `Kino.Toast.custom/2`.","ref":"Kino.Toast.html#error/2"},{"type":"function","title":"Kino.Toast.info/2","doc":"Creates an info toast with default styling.\n\nTo customize, use `Kino.Toast.custom/2`.","ref":"Kino.Toast.html#info/2"},{"type":"function","title":"Kino.Toast.new/1","doc":"Creates a new instance of the Kino.Toast component.","ref":"Kino.Toast.html#new/1"},{"type":"function","title":"Kino.Toast.queue/2","doc":"Enqueue one or more toasts to be displayed in the toast container.","ref":"Kino.Toast.html#queue/2"},{"type":"function","title":"Kino.Toast.success/2","doc":"Creates a success toast with default styling.\n\nTo customize, use `Kino.Toast.custom/2`.","ref":"Kino.Toast.html#success/2"},{"type":"function","title":"Kino.Toast.warning/2","doc":"Creates a warning toast with default styling.\n\nTo customize, use `Kino.Toast.custom/2`.","ref":"Kino.Toast.html#warning/2"},{"type":"module","title":"Kino.Toast.Icons","doc":"Provides a type-safe list of all supported free FontAwesome icons.","ref":"Kino.Toast.Icons.html"},{"type":"type","title":"Kino.Toast.Icons.fa_icon/0","doc":"A string representing a supported FontAwesome icon.\n\nSee the full list in `Kino.Toast.Icons.icons/0` or visit [FontAwesome Free Icons](https://fontawesome.com/icons).","ref":"Kino.Toast.Icons.html#t:fa_icon/0"},{"type":"function","title":"Kino.Toast.Icons.html/2","doc":"Generates a FontAwesome HTML tag for the icon with the given text color.\nRaises if invalid.","ref":"Kino.Toast.Icons.html#html/2"},{"type":"function","title":"Kino.Toast.Icons.icons/0","doc":"Returns the list of valid FontAwesome free icon names.","ref":"Kino.Toast.Icons.html#icons/0"},{"type":"function","title":"Kino.Toast.Icons.valid?/1","doc":"Validates whether the given string is a supported icon.","ref":"Kino.Toast.Icons.html#valid?/1"},{"type":"extras","title":"Readme","doc":"[![Hex.pm](https://img.shields.io/hexpm/v/kino_toast.svg)](https://hex.pm/packages/kino_toast)\n[![CI](https://github.com/arosenb2/kino_toast/actions/workflows/ci.yml/badge.svg)](https://github.com/arosenb2/kino_toast/actions/workflows/ci.yml)\n\n# Kino Toast\n\nA Kino component that adds dismissable notifications in a Livebook Cell.","ref":"readme.html"},{"type":"extras","title":"🚀 Features - Readme","doc":"- Create dismissable notifications for within a Livebook Cell.\n- Use built-in options or customize the notifications.","ref":"readme.html#features"},{"type":"extras","title":"📖 Getting Started - Readme","doc":"","ref":"readme.html#getting-started"},{"type":"extras","title":"Requirements - Readme","doc":"- Elixir >= 1.14\n- Kino >= 0.16\n- Livebook","ref":"readme.html#requirements"},{"type":"extras","title":"Try it in Livebook - Readme","doc":"Click the button below to launch the notebook in Livebook:\n\n[![Run in Livebook](https://livebook.dev/badge/v1/blue.svg)](https://livebook.dev/run?url=https%3A%2F%2Fgithub.com%2Farosenb2%2Fkino_toast%2Fblob%2Fmain%2Fkino_toast.livemd)","ref":"readme.html#try-it-in-livebook"},{"type":"extras","title":"Running Locally - Readme","doc":"```bash\nmix deps.get\nmix run\n```\n\nOr, if you’re using Livebook:\n\t1.\tOpen Livebook\n\t2.\tPaste the notebook URL or upload it locally","ref":"readme.html#running-locally"},{"type":"extras","title":"🤝 Contributing - Readme","doc":"See `CONTRIBUTORS.md` for contributor guidelines.","ref":"readme.html#contributing"},{"type":"extras","title":"📄 License - Readme","doc":"This project is licensed under the terms of the MIT License.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\n## [0.1.6] - 2025-06-05","ref":"changelog.html"},{"type":"extras","title":"Updated - Changelog","doc":"- Updated changelog after a few missing entries\n\n## [0.1.5] - 2025-06-05","ref":"changelog.html#updated"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fixed improper formatting for LiveBook\n\n## [0.1.4] - 2025-06-05","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Custom grouping for documentation\n\n## [0.1.3] - 2025-06-05","ref":"changelog.html#added"},{"type":"extras","title":"Updated - Changelog","doc":"- Updated module documentation\n\n## [0.1.2] - 2025-06-05","ref":"changelog.html#updated-1"},{"type":"extras","title":"Added - Changelog","doc":"- Additional links in Mix package\n\n## [0.1.1] - 2025-06-05","ref":"changelog.html#added-1"},{"type":"extras","title":"Added - Changelog","doc":"- `@doc` for `Kino.Toast.queue/2`","ref":"changelog.html#added-2"},{"type":"extras","title":"Fixed - Changelog","doc":"- Properly handles `nil` and `[]` in `Kino.Toast.queue/2`\n\n## [0.1.0] - 2025-06-04","ref":"changelog.html#fixed-1"},{"type":"extras","title":"Added - Changelog","doc":"- Initial release of `Kino.Toast` for Livebook\n- Custom toast notifications with emoji or FontAwesome icon support\n- Background/text color customization","ref":"changelog.html#added-3"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) 2025 Aaron Rosenbaum\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights to\nuse, copy, modify, merge, publish, distribute, sublicense, and/or sell copies\nof the Software, and to permit persons to whom the Software is furnished to do\nso, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"},{"type":"extras","title":"Livebook","doc":"# Kino.Toast\n\n```elixir\nMix.install([\n  {:kino, \"~> 0.16.0\"},\n  {:kino_toast, \"~> 0.1.0\"}\n])\n```","ref":"kino_toast.html"},{"type":"extras","title":"Example - Livebook","doc":"```elixir\ntoast = Kino.Toast.new(max_toasts: 3)\nKino.render(toast)\n```\n\n```elixir\nbutton = Kino.Control.button(\"Launch Toasts\")\nKino.render(button)\n```\n\n```elixir\nKino.listen(button, fn _event ->\n  Kino.Toast.queue(toast, Kino.Toast.warning(\"Enqueued as a single alert.\"))\n\n  Kino.Toast.queue(toast, [\n    Kino.Toast.info(\"You can use built-in toast templates or make a custom one.\"),\n    Kino.Toast.custom(\"This is a  Custom Toast .\", icon: \"bell\"),\n    Kino.Toast.success(\"Messages are enqueued to only show a fixed number at a time.\"),\n    Kino.Toast.error(\"You can even use  HTML  in the message.\")\n  ])\nend)\n\nKino.nothing()\n```","ref":"kino_toast.html#example"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}